@@ -35,7 +35,7 @@
 #include <QString>
 #include <QProcess>
 
-TouchFreezeApp::TouchFreezeApp( int argc, char* argv[] ) : QApplication( argc, argv )
+TouchFreezeApp::TouchFreezeApp( int& argc, char* argv[] ) : QApplication( argc, argv )
 {
   if ( !QSystemTrayIcon::isSystemTrayAvailable() )
   {
