@@ -37,7 +37,7 @@ class TouchFreezeApp: public QApplication
 {
 Q_OBJECT
 public:
-  TouchFreezeApp( int argc, char* argv[] );
+  TouchFreezeApp( int& argc, char* argv[] );
   virtual ~TouchFreezeApp();
 
 protected:
